@@ -150,6 +150,14 @@ class ConfigData:
                         _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
                         self.fieldmap[tv] = {"device": self.switches[k], "stateName": tk}
 
+                if v["type"] == 'TimedSwitch':
+                    _LOGGER.debug("  TimedSwitch - {0}".format(k))
+                    self.switches[k] = LoxSwitch(k, v["name"], v["type"], roomName, catName, v["details"])
+
+                    for tk,tv in v["states"].items():
+                        _LOGGER.debug("    state: {0} = {1}".format(tv, tk))
+                        self.fieldmap[tv] = {"device": self.switches[k], "stateName": tk}
+
                 if v["type"] == 'Window':
                     _LOGGER.debug("  Window - {0}".format(k))
                     self.windows[k] = LoxWindow(k, v["name"], v["type"], roomName, catName, v["details"])
@@ -159,7 +167,6 @@ class ConfigData:
                         self.fieldmap[tv] = {"device": self.windows[k], "stateName": tk}
 
 #IRCV2Daytimer
-#TimedSwitch
 #Daytimer
 #Tracker
 
