@@ -72,5 +72,16 @@ class LoxSwitch:
 
             self.async_update()
 
+        elif self._device_type == "TimedSwitch" and stateName == "deactivationDelay":
+            _LOGGER.debug("id:'{0}', name:'{1}', [SetValue Switch] - deactivationDelay={2}".format(self._id, self._name, value))
+            if value == 0: 
+                self._state = False
+            elif value == -1:
+                self._state = True
+            else:
+                self._state = True
+
+            self.async_update()
+
         else:
             _LOGGER.debug("id:'{0}', name:'{1}', [ValueNotSet {2}] - {3}={4}".format(self._id, self._name, self._device_type, stateName, value))
