@@ -20,7 +20,7 @@ class WSClient:
 
     def __init__(self, loop, host, port, username, password, async_session_callback, async_message_callback):
         """init"""
-        #_LOGGER.debug("__init__")
+        _LOGGER.debug("__init__")
         self.loop = loop
         self.session = None
         self.ws = None
